/*
 * Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
import 'package:amplify_core/amplify_core.dart';

part 'auth_user_request.g.dart';

/// {@template amplify_core.auth.auth_user_request}
/// Encapsulates parameters for a request for the current user.
/// {@endtemplate}
@zAmplifyGenericSerializable
class AuthUserRequest<Options extends AuthUserOptions>
    with AWSEquatable<AuthUserRequest<Options>>, AWSSerializable {
  /// {@macro amplify_core.auth.auth_user_request}
  const AuthUserRequest({this.options});

  factory AuthUserRequest.fromJson(
    Map<String, Object?> json,
    Options Function(Map<String, Object?>) fromJsonOptions,
  ) =>
      _$AuthUserRequestFromJson(
        json,
        (json) => fromJsonOptions((json as Map).cast()),
      );

  /// Additional, plugin-specific options to the request.
  final Options? options;

  @Deprecated('Use toJson instead')
  Map<String, Object?> serializeAsMap() => toJson();

  @override
  List<Object?> get props => throw UnimplementedError();

  @override
  Map<String, Object?> toJson() => _$AuthUserRequestToJson(
        this,
        (Options options) => options.toJson(),
      );
}
